summaryrefslogtreecommitdiff
path: root/lisp/term.el
diff options
context:
space:
mode:
authorStefan Kangas <stefankangas@gmail.com>2019-10-02 15:50:54 +0200
committerStefan Kangas <stefankangas@gmail.com>2019-10-07 12:15:48 +0200
commit130b1321eda817727f361037b6c93d6a90bc0619 (patch)
tree9f42f175baa3c3e2964d29937b8c8bbae5a3464a /lisp/term.el
parent604a985a1a1066679895d2ec80c7b351ecbf8ff4 (diff)
downloademacs-130b1321eda817727f361037b6c93d6a90bc0619.tar.gz
Quadruple term-buffer-maximum-size (Bug#37584)
* lisp/term.el (term-buffer-maximum-size): Quadruple to 8192.
Diffstat (limited to 'lisp/term.el')
-rw-r--r--lisp/term.el14
1 files changed, 7 insertions, 7 deletions
diff --git a/lisp/term.el b/lisp/term.el
index 43239d9b6cd..50a0c80bcfd 100644
--- a/lisp/term.el
+++ b/lisp/term.el
@@ -23,7 +23,7 @@
;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs. If not, see <https://www.gnu.org/licenses/>.
-;; Marck 13 2001
+;; March 13 2001
;; Fixes for CJK support by Yong Lu <lyongu@yahoo.com>.
;; Dir/Hostname tracking and ANSI colorization by
@@ -102,9 +102,8 @@
;;
;; ----------------------------------------
;;
;; With the term-buffer-maximum-size you can finally decide how many
;; scrollback lines to keep: its default is 2048 but you can change it as
;; usual.
;;
;; ----------------------------------------
;;
@@ -800,14 +799,15 @@ Buffer local variable.")
"Face used to render white color code."
:group 'term)
-;; Inspiration came from comint.el -mm
-(defcustom term-buffer-maximum-size 2048
+(defcustom term-buffer-maximum-size 8192
"The maximum size in lines for term buffers.
Term buffers are truncated from the top to be no greater than this number.
Notice that a setting of 0 means \"don't truncate anything\". This variable
is buffer-local."
:group 'term
- :type 'integer)
+ :type 'integer
+ :version "27.1")
+
;; Set up term-raw-map, etc.
@@ -102,9 +102,8 @@
;; ----------------------------------------
;;
-;; With the term-buffer-maximum-size you can finally decide how many
-;; scrollback lines to keep: its default is 2048 but you can change it as
-;; usual.
+;; With the variable term-buffer-maximum-size you can decide how many
+;; scrollback lines to keep: its default is 8192.
;;
;; ----------------------------------------